@@ -944,6 +944,28 @@ import_vpn_cb (GtkButton *button, gpointer user_data)
 	vpn_import (import_success_cb, (ActionInfo *) user_data);
 }
 
+static void
+vpn_export_get_secrets_cb (NMRemoteConnection *connection,
+                           GHashTable *secrets,
+                           GError *error,
+                           gpointer user_data)
+{
+	NMConnection *tmp;
+
+	/* We don't really care about errors; if the user couldn't authenticate
+	 * then just let them export everything except secrets.  Duplicate the
+	 * connection so that we don't let secrets sit around in the original
+	 * one.
+	 */
+	tmp = nm_connection_duplicate (NM_CONNECTION (connection));
+	g_assert (tmp);
+	if (secrets)
+		nm_connection_update_secrets (tmp, NM_SETTING_VPN_SETTING_NAME, secrets, NULL);
+	vpn_export (tmp);
+	g_object_unref (tmp);
+}
+
+
 static void
 export_vpn_cb (GtkButton *button, gpointer user_data)
 {
@@ -951,8 +973,13 @@ export_vpn_cb (GtkButton *button, gpointer user_data)
 	NMRemoteConnection *connection;
 
 	connection = get_active_connection (info->treeview);
-	if (connection)
-		vpn_export (NM_CONNECTION (connection));
+	if (connection) {
+		/* Grab secrets if we can */
+		nm_remote_connection_get_secrets (connection,
+		                                  NM_SETTING_VPN_SETTING_NAME,
+		                                  vpn_export_get_secrets_cb,
+		                                  NULL);
+	}
 }
 
 static void
@@ -1287,7 +1314,11 @@ add_connection_tab (NMConnectionList *self,
 	g_free (name);
 
 	/* Notebook tab */
+#if GTK_CHECK_VERSION(3,1,6)
+        hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
+#else
 	hbox = gtk_hbox_new (FALSE, 6);
+#endif
 	if (pixbuf) {
 		GtkWidget *image;
 
@@ -1545,8 +1576,9 @@ static void
 connections_read (NMRemoteSettings *settings, EditData *data)
 {
 	NMConnection *connection;
+	static gulong signal_id = 0;
 
-	connection = get_connection (data->self->settings, data->uuid);
+	connection = get_connection (settings, data->uuid);
 	if (connection) {
 		NMSettingConnection *s_con;
 		const char *type;
@@ -1566,8 +1598,8 @@ connections_read (NMRemoteSettings *settings, EditData *data)
 		g_object_unref (connection);
 	} else if (data->wait) {
 		data->wait = FALSE;
-		g_signal_connect (data->self->settings, "connections-read",
-		                  G_CALLBACK (connections_read), data);
+		signal_id = g_signal_connect (settings, "connections-read",
+		                              G_CALLBACK (connections_read), data);
 		return;
 	} else {
 		error_dialog (NULL,
@@ -1575,6 +1607,11 @@ connections_read (NMRemoteSettings *settings, EditData *data)
 		              _("Did not find a connection with UUID '%s'"), data->uuid);
 	}
 
+	if (signal_id != 0) {
+		g_signal_handler_disconnect (settings, signal_id);
+		signal_id = 0;
+	}
+
 	g_free (data);
 }
 
